==> jboss-eap-7.4.0.Beta-server-migration-src.zip: jboss-eap-7.4-server-migration-src/servers/wildfly20.0/src/main/java/org/jboss/migration/wfly/WildFly20_0ServerProvider.java <==
/*
 * Copyright 2020 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.migration.wfly;

import org.jboss.migration.core.ProductInfo;
import org.jboss.migration.core.Server;
import org.jboss.migration.core.env.MigrationEnvironment;
import org.jboss.migration.wfly10.dist.full.WildFlyFullServerProvider10_0;

import java.nio.file.Path;

/**
 * The WildFly 20.0 {@link org.jboss.migration.core.ServerProvider}.
 *  @author emmartins
 */
public class WildFly20_0ServerProvider extends WildFlyFullServerProvider10_0 {

    @Override
    protected String getProductModuleId() {
        return "org.jboss.as.product";
    }

    @Override
    protected String getProductVersionRegex() {
        return "20.0\\..*";
    }

    @Override
    protected Server constructServer(String migrationName, ProductInfo productInfo, Path baseDir, MigrationEnvironment migrationEnvironment) {
        return new WildFly20_0Server(migrationName, productInfo, baseDir, migrationEnvironment);
    }

    @Override
    public String getName() {
        return "WildFly 20.x";
    }
}

==> jboss-eap-8.0.0.Beta-server-migration-src.zip: jboss-eap-7.4-server-migration-src/servers/wildfly27.0/src/main/java/org/jboss/migration/wfly/WildFly27_0ServerProvider.java <==
/*
 * Copyright 2021 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.migration.wfly;

import org.jboss.migration.core.ProductInfo;
import org.jboss.migration.core.Server;
import org.jboss.migration.core.env.MigrationEnvironment;
import org.jboss.migration.wfly10.dist.full.WildFlyFullServerProvider10_0;

import java.nio.file.Path;

/**
 * The WildFly 27.x {@link org.jboss.migration.core.ServerProvider}.
 *  @author emmartins
 */
public class WildFly27_0ServerProvider extends WildFlyFullServerProvider10_0 {

    @Override
    protected String getProductModuleId() {
        return "org.jboss.as.product";
    }

    @Override
    protected String getProductVersionRegex() {
        return "27\\..*";
    }

    @Override
    protected Server constructServer(String migrationName, ProductInfo productInfo, Path baseDir, MigrationEnvironment migrationEnvironment) {
        return new WildFly27_0Server(migrationName, productInfo, baseDir, migrationEnvironment);
    }

    @Override
    public String getName() {
        return "WildFly 27.x";
    }
}
